﻿using appbyhwsw.Manager;
using appbyhwsw.Model;
using appbyhwsw.Views;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Runtime.CompilerServices;
using System.Text;
using Windows.Devices.Geolocation;
using Windows.Devices.Geolocation.Geofencing;
using Windows.UI.Core;
using Windows.UI.Popups;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace appbyhwsw.ViewModels
{
    public class NewsViewModel : INotifyPropertyChanged
    {
        private ObservableCollection<NewsItem> _news { get; set; }

        public ObservableCollection<NewsItem> News
        {
            get
            {
                return _news;
            }

            set
            {
                _news = value;
                NotifyPropertyChanged();
            }
        }

        public NewsViewModel()
        {
            Init();
        }

        public async void Init()
        {
            var nm = new NetworkManager();
            News = await nm.GetFeed();

            GeofenceMonitor.Current.GeofenceStateChanged += Current_GeofenceStateChanged;
            CreateGeofence();
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged([CallerMemberName] string propertyName = null)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        async void Current_GeofenceStateChanged(GeofenceMonitor sender, object args)
        {
            var reports = sender.ReadReports();
            var window = Windows.ApplicationModel.Core.CoreApplication.MainView.CoreWindow;

            await window.Dispatcher.RunAsync(CoreDispatcherPriority.Normal,
                async () =>
                {
                    foreach (GeofenceStateChangeReport report in reports)
                    {
                        GeofenceState state = report.NewState;

                        Geofence geofence = report.Geofence;

                        if (state == GeofenceState.Removed)
                        {
                            // remove the geofence from the geofences collection
                            GeofenceMonitor.Current.Geofences.Remove(geofence);
                        }
                        else if (state == GeofenceState.Entered)
                        {
                            // Your app takes action based on the entered event

                            // NOTE: You might want to write your app to take particular
                            // action based on whether the app has internet connectivity.

                            var dialog = new MessageDialog("You are in Yas Marina");
                            await dialog.ShowAsync();
                            ((Frame)Window.Current.Content).Navigate(typeof(Map),
                                new BasicGeoposition
                                {
                                    Latitude = 24.4672409,
                                    Longitude = 54.6079116
                                }
                                );

                        }
                        else if (state == GeofenceState.Exited)
                        {
                            // Your app takes action based on the exited event

                            // NOTE: You might want to write your app to take particular
                            // action based on whether the app has internet connectivity.

                        }
                    }
                });
        }

        private void CreateGeofence()
        {
            Geofence geofence = null;

            BasicGeoposition position;
            position.Latitude = 24.4672409;
            position.Longitude = 54.6079116;
            position.Altitude = 0.0;

            // the geofence is a circular region
            Geocircle geocircle = new Geocircle(position, 20000);

            // want to listen for enter geofence, exit geofence and remove geofence events
            // you can select a subset of these event states
            MonitoredGeofenceStates mask = 0;

            mask |= MonitoredGeofenceStates.Entered;
            mask |= MonitoredGeofenceStates.Exited;
            mask |= MonitoredGeofenceStates.Removed;

            geofence = new Geofence("yasmarina", geocircle, mask, false,
                TimeSpan.FromSeconds(5),
                DateTimeOffset.Now, TimeSpan.FromDays(1));


            if (GeofenceMonitor.Current.Geofences.Count > 0)
                GeofenceMonitor.Current.Geofences.RemoveAt(0);

            GeofenceMonitor.Current.Geofences.Add(geofence);

        }

    }
}
